pub struct Catalog { /* private fields */ }Expand description
One verified, sanitized Codex model catalog.
Implementations
Sourceimpl Catalog
impl Catalog
Sourcepub fn executable(&self) -> &str
pub fn executable(&self) -> &str
Codex executable whose version produced this catalog.
Sourcepub fn model_limits(&self, model: &str) -> Option<ModelLimits>
pub fn model_limits(&self, model: &str) -> Option<ModelLimits>
Returns the advertised limits for model when it exists.
Sourcepub async fn validation_is_cached(&self, scope: &str) -> Result<bool>
pub async fn validation_is_cached(&self, scope: &str) -> Result<bool>
Reports whether a successful compatibility validation is cached.
The caller must change scope whenever the configuration being
validated changes. Catalog and Codex-version changes are incorporated
automatically.
Sourcepub async fn cache_validation(&self, scope: &str) -> Result<()>
pub async fn cache_validation(&self, scope: &str) -> Result<()>
Records that the compatibility validation identified by scope passed.