pub struct ModelLimits {
pub context_window_tokens: u64,
pub max_input_tokens: u64,
}Expand description
Effective limits advertised for one Codex model.
Fields
context_window_tokens: u64Effective context-window size after Codex’s advertised percentage.
max_input_tokens: u64Maximum input size Kennedy may send to the model.
Implementations
Sourceimpl ModelLimits
impl ModelLimits
Sourcepub fn context_window_tokens(self) -> u64
pub fn context_window_tokens(self) -> u64
Effective context-window size after Codex’s advertised percentage.
Sourcepub fn max_input_tokens(self) -> u64
pub fn max_input_tokens(self) -> u64
Maximum input size Kennedy may send to the model.